@@ -22,11 +22,11 @@ def updateHistoryActions(isTest):
 def testFunc(isTest):
 	#disposeData(isTest)
 	es.setEnv(isTest)
-	#hot.startUpdate(isTest, 'config.ini')
+	hot.startUpdate(isTest, 'config.ini')
 	#print(es.searchDbConfig())
 	#print('delete post works record: ' + ('success ' if dataDispose.deletePastWorksRecord() else 'fail '))
 	#dataDispose.deletePastWorksRecord()
-	test.test()
+	#test.test()
 	'''
 	while True:
 		es.setEnv(isTest)
