@@ -29,14 +29,25 @@ def getIntByVid(vid):
 		vidDict[vid] = i
 		return i
 
-recommendRedisPool = redis.ConnectionPool(host='r-bp160ebab6e97594.redis.rds.aliyuncs.com', port='6379', password='flrjovlOJEROIJ324')
+recommendRedis0Pool = redis.ConnectionPool(host='r-bp160ebab6e97594.redis.rds.aliyuncs.com', port='6379', db=0, password='flrjovlOJEROIJ324')
+recommendRedis1Pool = redis.ConnectionPool(host='r-bp160ebab6e97594.redis.rds.aliyuncs.com', port='6379', db=1, password='flrjovlOJEROIJ324')
 
 def getIntByVidInRedis(vid):
-	recommendRedis = redis.Redis(connection_pool=recommendRedisPool, db=0)
-	#return recommendRedis.get(vid)
-	print(recommendRedis.get(vid))
-	#print(recommendRedis.lrange('recommendcache:videouserrecord:uid;177701952', 0, sys.maxint))
+	r = redis.Redis(connection_pool=recommendRedis0Pool)
+	return r.get('recommendcache:videointid:vid;' + vid)
 
+def getIntsByUid(uid):
+	r = redis.Redis(connection_pool=recommendRedis1Pool)
+	rInts = []
+	for ints in r.lrange('recommendcache:videouserrecord:uid;' + str(uid), 0, sys.maxint):
+		rInts += ints.split(',')
+	return rInts
+
+def writeIntsByUid(uid, rInts):
+	if len(rInts) == 0:
+		return
+	r = redis.Redis(connection_pool=recommendRedis1Pool)
+	r.lpush('recommendcache:videouserrecord:uid;' + str(uid), ','.join(rInts))
 
 def updateRedisWorksHots(worksHots):
 	r = redis.Redis(host='r-wz9536616f776d74.redis.rds.aliyuncs.com', port=6379, db=3, password='Idltest503') if isTest else redis.Redis(host='r-bp17063fe90e0e64.redis.rds.aliyuncs.com', port=6379, db=0, password='flrjovlOJEROIJ324')
@@ -57,6 +68,14 @@ def updateRedisWorksHots(worksHots):
 
 	return True
 
+def getAllUids(lastUid):
+	db = MySQLdb.connect("rm-bp10y51s402rn0kut.mysql.rds.aliyuncs.com", "mitaoroot", "lks213#%%Jfiewrj", "db_nt_user", charset='utf8')
+	uids = []
+	for item in searchDb(db, 'select uid from tb_user where uid > ' + str(lastUid) + ' order by uid asc limit 5000'):
+		uids.append(item[0])
+	db.close()
+	return uids
+
 def searchDbConfig():
 	config = {'hotVids': [], 'aidWeights': {}, 'vidWeights': {}}
 	
@@ -129,8 +148,8 @@ def clearStatisticsData(index):
 	deleteStatisticsData('statistics_' + index + '_write', {"query":{"match_all":{}}})
 
 def deleteStatisticsData(fullIndex, body, doc_type='data'):
-	success = len(getEsclient().delete_by_query(index=fullIndex, doc_type=doc_type, body=body, conflicts='proceed', preference='_primary_first')['failures']) == 0
-	getEsclient().delete_by_query(index=fullIndex, doc_type=doc_type, body=body, conflicts='proceed')
+	success = len(getEsclient(fullIndex).delete_by_query(index=fullIndex, doc_type=doc_type, body=body, conflicts='proceed', preference='_primary_first')['failures']) == 0
+	getEsclient(fullIndex).delete_by_query(index=fullIndex, doc_type=doc_type, body=body, conflicts='proceed')
 	return success
 
 def updateStatisticsData(index, dataDict):
@@ -170,7 +189,12 @@ def updateStatisticsDocResolve(index, doc):
 
 
 def esUpdateStatisticsDocResolve(es, index, doc, doc_type='data'):
-	return not es.bulk(index='statistics_' + index + '_write', doc_type=doc_type, body=doc)['errors']
+	result = es.bulk(index='statistics_' + index + '_write', doc_type=doc_type, body=doc)
+	if result['errors']:
+		#print(result)
+		return False
+	else:
+		return True
 
 def searchStatisticsAggs(index, body):
 	fullIndex = 'statistics_' + index + '_read'
@@ -223,7 +247,7 @@ def scrollSearch(fullIndex, doc_type, body, searchAll=True, log=True, version=Fa
 	return hits
 
 def getEsclient(fullIndex=None):
-	return testEsclient if isTest else relEsclient if fullIndex == 'works_video_read' else localEsclient if fullIndex in ['statistics_works_hot_grow_write', 'statistics_works_hot_simulation_write', 'statistics_works_history_read', 'statistics_works_history_write'] else dataEsclient
+	return testEsclient if isTest else relEsclient if fullIndex == 'works_video_read' else localEsclient if fullIndex in ['statistics_works_hot_grow_write', 'statistics_works_hot_simulation_write', 'statistics_works_history_simulation_read', 'statistics_works_history_simulation_write'] else dataEsclient
 
 def timeToEsLocalTime(pTime):
 	return time.strftime('%Y-%m-%dT%H:%M:%S+0800', time.localtime(pTime))
