@@ -1,25 +1,63 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import time
-from .. import es, dataDispose
+import time, gc
+from .. import es, dataDispose, imatrix
+from numpy import *
 
 def test():
-	recordEsToRedis()
+	ab = mat([[1, 2, 3, 4], [0.3, 3, 4, 0.1], [3, 1, 3, 5], [10, 3, 100, 30], [9, 30, 40, 99], [99, 65, 0, 39]])
+	print(ab)
+	print('----------')
+	print(imatrix.inOneDiv(ab))
+	print('----------')
+	print(imatrix.inOneDivOffStray(ab))
+	#recordEsToRedis()
 	#hotGrow()
+	'''
+	l = [[1]]
+	for i in range(0, 5000):
+		l.append([0.0001])
+	for i in range(0, 5000):
+		l.append([0.0002])
+	print(imatrix.inOne(mat(l)))
+	'''
 
 def recordEsToRedis():
+	currentUid = readEndUid()
+	index = 0
+	while True:
+		nextUids = es.getAllUids(currentUid)
+		if len(nextUids) == 0:
+			break
+		for nextUid in nextUids:
+			hitInts = []
+			existInts = es.getIntsByUid(nextUid)
+			hits = es.scrollSearch('statistics_works_hot_fixed_backups', 'recommendviewrecordsearch', {"query":{"bool":{"must":[{"range":{"time":{"lte":1548644400000}}},{"term":{"uid":{"value":nextUid}}}]}},"size":10000})
+			for hit in hits:
+				i = es.getIntByVid(hit['_parent'])
+				if i != None and i not in existInts:
+					hitInts.append(str(i))
+			index += 1
+			print(index, nextUid, len(hitInts))
+			es.writeIntsByUid(nextUid, hitInts)
+			writeEndUid(nextUid)
+			writeUids(nextUid)
+			currentUid = nextUid
+		gc.collect()
 	
-	i = es.getIntByVid('recommendcache:videointid:vid;c64bbec3105d385fd137b5a97fd56259')
-
 def readEndUid():
 	with open('endUid.ini', 'r') as f:
-		return float(f.read())
+		return long(f.read())
 
 def writeEndUid(uid):
 	with open('endUid.ini', 'w') as f:
 		f.write(str(uid))
 
+def writeUids(uid):
+	with open('uids', 'a') as f:
+		f.write('{"uid":' + str(uid) + ',"r1size":8,"r2size":2}\n')
+
 def hotGrow():
 	for vid in ["8133878fd33659cd57fac322e6e08e53", "b9ee6b64790042a3de02b430edd359c1", "2cdef127c294230a2d86438a79c4db3f", "54423e3437395068981e503ec646e682", "c9c2ad4ab7c4c3680e7d0ef5b0c909c9", "ab68fbda808b6c5ab1c84e43c3a1aedc", "a39f8db3de774426e5500b468adcd3b0"]:
 		growDict = {}
